@@ -2,9 +2,8 @@
 # this repository contains the full copyright notices and license terms.
 
 from trytond.pool import Pool
-from . import dunning
-from . import party
-from . import account
+
+from . import account, dunning, party
 
 
 def register():
@@ -23,4 +22,5 @@ def register():
     Pool.register(
         dunning.CreateDunning,
         dunning.ProcessDunning,
+        dunning.RescheduleDunning,
         module='account_dunning', type_='wizard')
